@@ -1,5 +1,5 @@
 ## File Name: gom.em.alg.R
-## File Version: 5.18
+## File Version: 5.19
 
 
 
@@ -225,9 +225,7 @@
                                     }
                                 }
         diag(Sigma.cov) <- diag(Sigma.cov) + 10^(-10)
-        pi.k <- matrix( mvtnorm::dmvnorm( theta.k, mean=mu, sigma=Sigma.cov )    ,
-                        ncol=1 )
-        pi.k <- pi.k / sum( pi.k )
+        pi.k <- sirt_dmvnorm_discrete( theta.k, mean=mu, sigma=Sigma.cov, as_matrix=TRUE )
         res <- list("mu"=mu, "Sigma"=Sigma.cov, "pi.k"=pi.k )
         return(res)
                     }
