@@ -1,8 +1,8 @@
 ## File Name: summary.lsem.R
-## File Version: 0.35
+## File Version: 0.398
 
-#############################################
-# summary lsem
+
+#-- summary lsem
 summary.lsem <- function( object, file=NULL, digits=3, ... )
 {
     # open sink for a file
@@ -30,12 +30,29 @@ summary.lsem <- function( object, file=NULL, digits=3, ... )
     #-- print computation time
     sirt_summary_print_computation_time_s1(object=object)
 
-    cat( paste0( "Number of observations=", round(object$N,digits) ), "\n")
+    # space between equality sign
+    sp_eq <- paste0( c(" ", "=", " "), collapse="")
+
+    cat( paste0( "Number of observations", sp_eq, round(object$N,digits) ), "\n")
+    cat("Used samping weights:", ! object$no_sampling_weights, "\n")
     if ( object$type=="LSEM"){
-        cat( paste0( "Bandwidth factor=", round(object$h,digits) ), "\n")
-        cat( paste0( "Bandwidth=", round(object$bw,digits) ), "\n")
-        cat( paste0( "Number of focal points for moderator=",
+        cat( paste0( "Bandwidth factor", sp_eq, round(object$h,digits) ), "\n")
+        cat( paste0( "Bandwidth", sp_eq, round(object$bw,digits) ), "\n")
+        cat( paste0( "Number of focal points for moderator", sp_eq,
                             length(object$moderator.grid ) ), "\n")
+        cat("\n")
+        cat("Used joint estimation:", object$est_joint, "\n")
+        cat("Used sufficient statistics:", object$sufficient_statistics, "\n")
+        cat("Used pseudo weights:", object$use_pseudo_weights, "\n")
+        cat("Used lavaan package:", TRUE, "\n")
+        cat("Used lavaan.survey package:", object$use_lavaan_survey, "\n\n")
+        cat("Mean structure modelled:", object$is_meanstructure, "\n")
+
+        if (object$class_boot){
+            v1 <- paste0("\nStatistical inference based on ", object$R, " bootstrap samples.")
+            cat(v1,"\n")
+        }
+
     }
 
     if ( object$type=="MGM"){
@@ -46,6 +63,13 @@ summary.lsem <- function( object, file=NULL, digits=3, ... )
     cat("\nlavaan Model\n")
     cat(object$lavmodel)
 
+    if (object$est_joint){
+        cat("\n\n")
+        cat("Global Fit Statistics for Joint Estimation\n\n")
+        obji <- object$fitstats_joint
+        sirt_summary_print_objects(obji=obji, digits=digits)
+    }
+
     cat("\n\n")
     cat("Parameter Estimate Summary\n\n")
     obji <- object$parameters_summary
@@ -53,6 +77,8 @@ summary.lsem <- function( object, file=NULL, digits=3, ... )
 
     cat("\n")
     cat("Distribution of Moderator: Density and Effective Sample Size\n\n")
+    cat( paste0("M=", round(object$m.moderator, digits), " | SD=",
+                round(object$sd.moderator, digits), "\n\n") )
     obji <- object$moderator.density
     sirt_summary_print_objects(obji=obji, digits=digits, from=1)
 
@@ -62,6 +88,4 @@ summary.lsem <- function( object, file=NULL, digits=3, ... )
 
     # close file
     sirt_csink(file)
-
 }
-#############################################
